@@ -2,10 +2,10 @@
 summary_VPA <- function(Assessment) {
   assign_Assessment_slots(Assessment)
 
-  if(conv) current_status <- c(F_FMSY[length(F_FMSY)], B_BMSY[length(B_BMSY)], B_B0[length(B_B0)])
+  if(conv) current_status <- c(F_FMSY[length(F_FMSY)], SSB_SSBMSY[length(SSB_SSBMSY)], SSB_SSB0[length(SSB_SSB0)])
   else current_status <- rep(NA, 3)
   current_status <- data.frame(Value = current_status)
-  rownames(current_status) <- c("F/FMSY", "B/BMSY", "B/B0")
+  rownames(current_status) <- c("F/FMSY", "SSB/SSBMSY", "SSB/SSB0")
 
   Value <- c(h, info$data$M[1], min(info$ages), max(info$ages), info$LH$Linf, info$LH$K, info$LH$t0,
              info$LH$a * info$LH$Linf ^ info$LH$b, info$LH$A50, info$LH$A95)
