@@ -177,7 +177,8 @@ rmd_MSY <- function(par = "MSYx") {
   c(paste0("```{r, fig.cap=\"", fig.cap, "\"}"),
     "if(conv) {",
     paste0("  msy.ind <- names(SD$par.fixed) == \"", par, "\""),
-    "  log.msy <- SD$par.fixed[msy.ind] - log(obj$env$data$rescale)",
+    "  log_rescale <- ifelse(is.null(obj$env$data$rescale), 0, log(obj$env$data$rescale))",
+    "  log.msy <- SD$par.fixed[msy.ind] - log_rescale",
     "  log.msy.sd <- sqrt(diag(SD$cov.fixed)[msy.ind])",
     "  plot_lognormalvar(log.msy, log.msy.sd, logtransform = TRUE, label = expression(widehat(MSY)))",
     "}",
